@@ -7,11 +7,11 @@ Poker::Eval::Bitch - Evaluate and score hole cards in the game of Bitch.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 INTRODUCTION
@@ -37,12 +37,14 @@ sub _build_bitch_card { # The Bitch
 
 sub best_hand {
   my ( $self, $hole ) = @_;
+  my $hand = Poker::Hand->new(cards => $hole);
   for my $card (@$hole) {
     if ($card->rank . $card->suit eq $self->bitch_card) {
-      return { score => 100, hand => $self->bitch_card };
+      $hand->score(100);
+      return $hand;
     }
   }
-  return { score => 0 };
+  return $hand;
 }
 
 =head1 AUTHOR
