@@ -7,11 +7,11 @@ Poker::Eval::HighSuit - Calculate the highest card of a specific suit.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 INTRODUCTION
@@ -33,7 +33,9 @@ sub _build_high_suit {    # High Chicago
 
 sub best_hand {
   my ( $self, $hole ) = @_;
-  return $self->scorer->score($hole, $self->high_suit);
+  my $hand = Poker::Hand->new(cards => $hole);
+  $hand->score($self->scorer->score($hole, $self->high_suit));
+  return $hand;
 }
 
 =head1 AUTHOR
